/* ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2000-2001 The Apache Software Foundation.  All rights
 * reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Apache" and "Apache Software Foundation" and
 *     "Apache Jetspeed" must not be used to endorse or promote products
 *    derived from this software without prior written permission. For
 *    written permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache" or
 *    "Apache Jetspeed", nor may "Apache" appear in their name, without
 *    prior written permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.apache.jetspeed.om.registry.base;

import java.util.Locale;

import org.apache.jetspeed.om.registry.NlsTitle;

/**
 * Bean like implementation of the Title interface suitable for
 * Castor serialization.
 *
 * @see org.apache.jetspeed.om.registry.NlsTitle
 * @author <a href="mailto:mamoruwa@hotmail.com">Mamoru WATANABE</a>
 * @version $Id: BaseNlsTitle.java,v 1.1 2003/03/16 14:22:51 shinsuke Exp $
 */
public class BaseNlsTitle implements NlsTitle, java.io.Serializable
{
    private String name;
    private String locale;

    /**
     * Implements the equals operation so that 2 elements are equal if
     * all their member values are equal.
     */
    public boolean equals(Object object)
    {
        if (object==null)
        {
            return false;
        }

        BaseNlsTitle obj = (BaseNlsTitle)object;

        if (name!=null)
        {
            if (!name.equals(obj.getName()))
            {
                return false;
            }
        }
        else
        {
            if (obj.getName()!=null)
            {
                return false;
            }
        }

        if (locale!=null)
        {
            if(!locale.equals(obj.getLocale()))
            {
                return false;
            }
        }
        else
        {
            if (obj.getLocale()!=null)
            {
                return false;
            }
        }

        return true;
    }

    /** @return the string Name */
    public String getName()
    {
        return name;
    }

    /** Sets the string Name
     *
     * @param value the new Name value
     */
    public void setName(String name)
    {
        this.name = name;
    }

    /** @return the string locale */
    public String getLocale()
    {
        return locale;
    }

    /** Sets the string locale
     *
     * @param value the new locale value
     */
    public void setLocale(String locale)
    {
        this.locale = locale;
    }

    /** @return the locale object */
    public Locale getLocaleObject()
    {
        if (this.locale == null) return null;

        String language = null;
        String country = null;
        String variant = null;
        int pos1 = 0;
        int pos2 = 0;

        pos1 = locale.indexOf("_", 0);
        if (pos1 > -1)
        {
            language = locale.substring(0, pos1);
            ++pos1;
        }
        else
        {
            language = locale;
            country = "";
            variant = "";
            pos1 = pos2 = locale.length();
        }

        if (pos1 < locale.length())
        {
            pos2 = locale.indexOf("_", pos1);
            if (pos2 > -1)
            {
                country = locale.substring(pos1, pos2);
                ++pos2;
            }
            else
            {
                country = locale.substring(pos1, locale.length());
                variant = "";
                pos2 = locale.length();
            }
        }

        if (pos2 < locale.length())
        {
            variant = locale.substring(pos2, locale.length());
        }
        else
        {
            variant = "";
        }

        return new Locale(language, country, variant);
    }

    /** Sets the locale object
     * 
     * @param value the new locale object
     */
    public void setLocaleObject(Locale locale)
    {
        if (locale == null)
        {
            this.locale = null;
        }
        else
        {
            this.locale = locale.toString();
        }
    }
}
